@@ -62,7 +62,7 @@
 module SiSU_DAL_DocumentStructure
   class Extract
     def extract(h,o)
-      obj=h ? h : o
+      h ? h : o
     end
   end
   class ObjectMetadata
@@ -106,7 +106,7 @@ module SiSU_DAL_DocumentStructure
       @tags=[]
     end
     def heading_ln(lv)
-      ln=case lv
+      case lv
       when /A/; 1
       when /B/; 2
       when /C/; 3
@@ -119,7 +119,7 @@ module SiSU_DAL_DocumentStructure
       end
     end
     def heading_lv(ln)
-      lv=case ln.to_s
+      case ln.to_s
       when /1/; 'A'
       when /2/; 'B'
       when /3/; 'C'
