@@ -97,7 +97,7 @@ module SiSU_DAL_Syntax
       tail_m_ital=%q{(?:\s|[.,;:?!'")]|~\^|~\\\{\s|$)}
       tail_m_bold=%{(?:(?:#{Mx[:fa_italics_c]})?(?:\s|[.,;:?!'")]|~\^|~\\\{\s|$))?}
       bold_line=%{^!_\s.+?(?:#{Mx[:br_line]}|\n|$)}
-      ital_line=%{^/_\s.+?(?:#{Mx[:br_line]}|\n|$)}
+      #ital_line=%{^/_\s.+?(?:#{Mx[:br_line]}|\n|$)} #not implemented
       @line_scan_ital=if defined? @md.italics_match_list[:str]
         /#{@http_m}|#{bold_line}|#{@manmkp_ital}#{tail_m_ital}|#{@md.italics_match_list[:str]}#{tail_m_ital}|\S+|\n/i
       elsif defined? @vz.markup_make_italic[:str]
