@@ -147,7 +147,6 @@ module SiSU_DbImport
           puts @conn.driver if defined? @conn.driver
         end
         begin
-          sql=''
           if @sql_type=~/sqlite/
             @conn.transaction do |conn|
               t_d.each do |sql|
@@ -270,10 +269,10 @@ module SiSU_DbImport
           data.obj.gsub!(/#{Mx[:tag_o]}\S+?#{Mx[:tag_c]}/,'') #check
           @col[:seg]=@@seg
           if data.of ==:para \
-          || :heading \
-          || :heading_insert \
-          || :block \
-          || :group      # regular text what of code-blocks grouped text etc.
+          || data.of ==:heading \
+          || data.of ==:heading_insert \
+          || data.of ==:block \
+          || data.of ==:group      # regular text what of code-blocks grouped text etc.
             notedata=data.obj.dup
                                                                                #% :headings
             if data.is==:heading \
@@ -590,17 +589,17 @@ module SiSU_DbImport
         @txt
       end
       def standard
-        x=(@txt =~/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/) \
+        (@txt =~/#{Mx[:en_a_o]}.+?#{Mx[:en_a_c]}/) \
         ? @txt.scan(/#{Mx[:en_a_o]}(\d+).+?#{Mx[:en_a_c]}/)
         : nil
       end
       def asterisk
-        x=(@txt =~/#{Mx[:en_b_o]}\*.+?#{Mx[:en_b_c]}/) \
+        (@txt =~/#{Mx[:en_b_o]}\*.+?#{Mx[:en_b_c]}/) \
         ? @txt.scan(/#{Mx[:en_b_o]}[*](\d+).+?#{Mx[:en_b_c]}/)
         : nil
       end
       def plus
-        x=(@txt =~/#{Mx[:en_b_o]}\+.+?#{Mx[:en_b_c]}/) \
+        (@txt =~/#{Mx[:en_b_o]}\+.+?#{Mx[:en_b_c]}/) \
         ? @txt.scan(/#{Mx[:en_b_o]}[+](\d+).+?#{Mx[:en_b_c]}/)
         : nil
       end
@@ -636,8 +635,6 @@ module SiSU_DbImport
       begin
         @fnc=content
         @env=SiSU_Env::InfoEnv.new(@opt.fns)
-        base=@env.url.root
-        out=@env.path.output
         f,u={},{}
         if @fnb.empty? \
         or @fnb.nil?
