@@ -92,7 +92,7 @@ module SiSU_DbSelect
     end
     def sql_maintenance_file
       file=if @opt.inspect =~/M/
-        x=if @opt.fns and not @opt.fns.empty?
+        if @opt.fns and not @opt.fns.empty?
           @env=SiSU_Env::InfoEnv.new(@opt.fns) if @opt.fns
           puts "\n#{@env.processing_path.sqlite}/#{@opt.fns}.sql" if @sql_type =~/sqlite/ and @opt.cmd =~/M/
           @db=SiSU_Env::InfoDb.new
