@@ -86,7 +86,6 @@ module SiSU_EPUB
         @md=@particulars.md
         @fnb=@md.fnb
         @env=@particulars.env
-        loc=@env.path.url.output_tell
         unless @opt.cmd =~/q/
           tool=(@opt.cmd =~/[MVvz]/) \
           ? "#{@env.program.epub_viewer} #{@md.file.output_path.epub.dir}/#{@md.file.base_filename.epub}"
@@ -98,15 +97,13 @@ module SiSU_EPUB
         end
         @env.processing_path.epub_bld #(@md)
         @env.processing_path.epub_cp_images(@md)
-        dir_epub=@env.processing_path.epub
         data=nil
         SiSU_Env::FileOp.new(@md).mkdir.output.epub
         @tuned_file_array=SiSU_EPUB::Source::XHTML_Environment.new(@particulars).tuned_file_instructions
         data=@tuned_file_array
-        scr_endnotes=SiSU_EPUB::Source::Endnotes.new(@md,data).scroll
         toc=SiSU_EPUB::Source::Toc.new(@md,data).songsheet
         data=@tuned_file_array
-        scr_toc=SiSU_EPUB::Source::ScrollHeadAndSegToc.new(@md,toc).in_common #watch
+        SiSU_EPUB::Source::ScrollHeadAndSegToc.new(@md,toc).in_common #watch
         SiSU_EPUB::Source::Seg.new(@md,data).songsheet
         SiSU_EPUB::Source::Output.new(@md).songsheet
       rescue
@@ -139,7 +136,6 @@ module SiSU_EPUB
         @env,@css=particulars.env,SiSU_Style::CSS.new
       end
       def directories
-        title=File.basename(@md.fns,'.rb')
         SiSU_Env::FileOp.new(@md).mkdir.output.epub
       end
       def tuned_file_instructions
@@ -157,7 +153,6 @@ module SiSU_EPUB
       end
       def scroll
         @scr_endnotes=[]
-        format_head_scroll=SiSU_EPUB_Format::HeadScroll.new(@md)
         @data.each do |dob|
           pg=dob.dup
           unless pg.is ==:code
@@ -376,10 +371,6 @@ module SiSU_EPUB
       def level_1
         dob=@data
         linkname,link=dob.obj.strip,dob.ocn
-        if link \
-        and link !~/#/ #% keep eye on link
-          p_num=SiSU_EPUB_Format::ParagraphNumber.new(@md,link)
-        end
         title=if dob.obj !~/Document Information/
           linkname
         else
