@@ -153,7 +153,7 @@ WOK
     end
   protected
     def articles(data)
-      track,tracking,newfile=0,0,0
+      tracking,newfile=0,0
       @@is4=@@is3=@@is2=@@is1=0
       printed_endnote_seg='n'
       idx_xhtml=nil
@@ -167,14 +167,14 @@ WOK
         || dob.is==:heading_insert) \
         and dob.ln==4
           @@seg_name << dob.name
-          seg_name=dob.name
+          dob.name
         end
       end
       @@seg_name_xhtml=@@seg_name
       @@seg_total=@@seg_name.length
       testforartnum=@@seg_name_xhtml
       SiSU_Screen::Ansi.new(@md.opt.cmd,@@seg_name.length) if @md.opt.cmd =~/[MVv]/
-      map_nametags=SiSU_Particulars::CombinedSingleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
+      SiSU_Particulars::CombinedSingleton.instance.get_map_nametags(@md).nametags_map #p map_nametags
       data.each do |dob|
         #if defined? dob.obj \
         #and dob.obj =~/href="#{Xx[:segment]}#+\S+?"/
@@ -220,7 +220,7 @@ WOK
           if not (dob.is==:heading \
           || dob.is==:heading_insert) \
           and dob.ln==1
-            head1=$_ #; check
+            $_ #; check
           end
         end
         if @@is4==1
