@@ -92,7 +92,6 @@ module SiSU_HTML
         @md=@particulars.md
         @fnb=@md.fnb
         @env=@particulars.env
-        loc=@env.url.output_tell
         primary_output_file=(@opt.act[:html_seg][:set]==:on) \
         ? (@md.file.output_path.html_seg.dir + '/' + @md.file.base_filename.html_segtoc)
         : (@md.file.output_path.html_scroll.dir + '/' + @md.file.base_filename.html_scroll)
@@ -200,7 +199,7 @@ module SiSU_HTML
       end
       def scroll
         @scr_endnotes=[]
-        format_head_scroll=SiSU_HTML_Format::HeadScroll.new(@md)
+        SiSU_HTML_Format::HeadScroll.new(@md)
         @data.each do |dob|
           pg=dob.dup
           unless pg.is ==:code
@@ -328,7 +327,7 @@ WOK
         linkname,link=dob.obj.strip,dob.ocn
         if link \
         and link !~/#/ #% keep eye on link
-          p_num=SiSU_HTML_Format::ParagraphNumber.new(@md,link)
+          SiSU_HTML_Format::ParagraphNumber.new(@md,link)
         end
         title=if dob.obj !~/Metadata/ then linkname
         else
@@ -345,10 +344,9 @@ WOK
         end
         toc[:seg_mini]=if dob.name =~/^meta/ \
         and dob.obj =~/Document Information/
-          x=if @md.concord_make
-            format_toc.mini_concord_tail
-          else format_toc.mini_tail
-          end
+          @md.concord_make \
+          ? format_toc.mini_concord_tail
+          : format_toc.mini_tail
         else format_toc.mini_lev1
         end
         title=if dob.ocn ==0
@@ -586,7 +584,7 @@ WOK
         if defined? @md.prefix_b
           toc_shared << prefix_b
         end
-        scr_toc=if @make.build.toc? #Table of Contents added/appended here
+        if @make.build.toc? #Table of Contents added/appended here
           toc_shared << @toc[:scr]
         end
         @segtoc << @links_guide_toc
