@@ -76,7 +76,6 @@ module SiSU
     def initialize(argv)
       pwd_the=Dir.pwd
       begin                                                              #% select what to do
-        home=ENV['HOME']
         opt=SiSU_Commandline::Options.new(argv)
         SiSU::Processing.new(opt).actions
       rescue
@@ -140,7 +139,6 @@ module SiSU
       end
     end
     def manifest_on_files_translated
-      r=Px[:lng_lst_rgx]
       number_of_files={}
       @opt.files.each_with_index do |fns,i|
         fn=fns.gsub(/(?:~(?:#{@r}))?\.ss[tm]$/,'')
@@ -514,7 +512,7 @@ module SiSU
     end
     def do_initialization
       @cX=SiSU_Screen::Ansi.new(@opt.cmd).cX
-      flag=SiSU_Env::InfoProcessingFlag.new
+      SiSU_Env::InfoProcessingFlag.new
       if @opt.act[:version_info][:set]==:on              #% version information
         SiSU_Env::InfoAbout.new(@opt).sisu_version
       end
@@ -573,7 +571,6 @@ module SiSU
       if @opt.act[:dal][:set]==:on
         @retry_count= -1
         begin
-          path_image='./_sisu/processing/external_document/image'
           @get_s,@get_p,@get_pl=[],[],[]
           re_s=/(\S+?\.-sst)$/
           re_p3=/((?:https?|file):\/\/\S+?(?:\/\S+?\.ss[mt]\.txz|sisupod(?:\.txz)?|\.ssp))/
@@ -700,7 +697,7 @@ module SiSU
         puts SiSU_Markup::MarkupHistory.new(@opt).query
       elsif @opt.mod.inspect =~/--identify/
         require_relative 'sst_identify_markup'          # sst_identify_markup.rb
-        markup_version=SiSU_Markup::MarkupIdentify.new(@opt).markup_version?
+        SiSU_Markup::MarkupIdentify.new(@opt).markup_version?
       elsif  @opt.mod.inspect =~/--sitemaps/           #% sitemaps
         require_relative 'sitemaps'                    # sitemaps.rb
         SiSU_Sitemaps::Source.new(@opt).read
