@@ -139,7 +139,7 @@ module SiSU_Manifest
       def url_make(url,file,src=nil)
         if @o_str.dump_or_redirect?
           ''
-        elsif :src
+        elsif src==:src #check
           %{<br />#{@brace_url.xml_open}<a href="#{url}/#{file}">#{url}/#{file}</a>#{@brace_url.xml_close}}
         else
           %{<p class="tiny">#{@brace_url.xml_open}<a href="#{url}/#{file}">#{url}/#{file}</a>#{@brace_url.xml_close}</p>}
@@ -208,14 +208,13 @@ module SiSU_Manifest
             @m << { mu: mu, l: lng, rel: mr }
           end
         end
-        manifests
         @m=@m.uniq
       end
       def languages(id,file)
         flv=published_manifests?
         @manifest[:html] << %{<tr><th class="left"><div id="horizontal_links"><ul id="horizontal">\n}
         flv.each do |l|
-          lang=SiSU_Translate::Source.new(@md,@language,l[:n]).language_list
+          SiSU_Translate::Source.new(@md,@language,l[:n]).language_list
           @manifest[:txt] << "#{l[:mu]} #{l[:l]}\n"
           @manifest[:html] << %{<li class="norm"><a href="#{l[:rel]}">#{l[:l]}</a>&nbsp;&nbsp;&nbsp;</li>}
         end
@@ -651,7 +650,7 @@ WOK
                 if st.is_a?(Array)
                   st.each do |v|
                     if v.is_a?(Array)
-                      v.each do |w,i|
+                      v.each do |w|
                         @manifest[:html] << %{<p class="it#{i}">#{w}</p>\n}
                       end
                     else
@@ -787,11 +786,7 @@ WOK
         begin
           make=SiSU_Env::ProcessingSettings.new(@md)
           minitoc=SiSU_HTML_MiniToc::TocMini.new(@md,data).songsheet.join("\n")
-          id,file='',''
           vz=SiSU_Viz::Defaults.new
-          search_form=(make.build.search_form?) \
-          ? "<td>#{@env.widget_static.search_form}</td>"
-          : ''
           format_head_toc=SiSU_HTML_Format::HeadToc.new(@md)
           @manifest[:html] <<<<WOK
 <!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
