@@ -236,8 +236,6 @@ module SiSU_Urls
       and opt.cmd =~/[abcehHmNoptwxXy]/ \
       and x=~/^[#{opt.cmd}]/ \
       and opt.cmd =~/[MV]/
-        m=$1
-        f=y
         tool=@prog.text_editor
         if x =~/^m/ \
         and @opt.cmd=~/m/ \
@@ -247,7 +245,7 @@ module SiSU_Urls
         if x=~/^([hw])/ \
         and @opt.cmd=~/[hw]/ \
         and x=~/^[#{@opt.cmd}]/ \
-        and x !~/segmented/; "#{y}.html"
+        and x !~/segmented/
           SiSU_Screen::Ansi.new(@opt.cmd,"-#{x}","#{@prog.text_editor} #{@env.processing_path.tune}/#{@md.fns}.tune").maintenance
         end
         if x=~/^p/ \
@@ -417,7 +415,7 @@ module SiSU_Urls
       i="(output manifest) [#{@opt.f_pth[:lng_is]}] #{@env.url.output_tell}/#{@fnb}/sisu_manifest.html"
       SiSU_Screen::Ansi.new(@opt.cmd,'URLs',i).grey_title_hi
       @u.each do |x,y|
-        tell=case x
+        case x
         when /^m/
           show.meta(x,y)
         when /^[BcdNsxXy]/
