@@ -84,8 +84,6 @@ module SiSU_XML_SAX
       begin
         @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
         unless @opt.cmd =~/q/
-          path=@env.path.output_tell
-          loc=@env.url.output_tell
           tool=if @opt.cmd =~/[MV]/; "#{@env.program.web_browser} file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}\n\t#{@env.program.xml_viewer} file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}"
           elsif @opt.cmd =~/v/; "#{@env.program.web_browser} file://#{@md.file.output_path.xml_sax.dir}/#{@md.file.base_filename.xml_sax}"
           else "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
@@ -216,8 +214,7 @@ WOK
       def xml_structure(dob,type='norm')
         if dob.is==:heading
           lv=dob.ln
-          n=dob.ln - 1
-          n3=dob.ln + 2
+          dob.ln + 2
         else lv=nil
         end
         extract_endnotes(dob)
@@ -404,7 +401,6 @@ WOK
       end
       def pre
         rdf=SiSU_XML_Tags::RDF.new(@md)
-        dir=SiSU_Env::InfoEnv.new
         @@xml[:head],@@xml[:body]=[],[]
         stylesheet=SiSU_Style::CSS_HeadInfo.new(@md,'xml_sax').stylesheet
         encoding=if @sys.locale =~/utf-?8/i; '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
