@@ -85,8 +85,6 @@ module SiSU_XML_DOM
       begin
         @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
         unless @opt.cmd =~/q/
-          path=@env.path.output_tell
-          loc=@env.url.output_tell
           tool=if @opt.cmd =~/[MV]/; "#{@env.program.web_browser}  file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}\n\t#{@env.program.xml_viewer} file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}"
           elsif @opt.cmd =~/v/; "#{@env.program.web_browser} file://#{@md.file.output_path.xml_dom.dir}/#{@md.file.base_filename.xml_dom}"
           else "[#{@opt.f_pth[:lng_is]}] #{@opt.fno}"
@@ -184,7 +182,7 @@ WOK
           n1=dob.ln
           n2=dob.ln + 1
           n3=dob.ln + 2
-          v=dob.ln - 3
+          dob.ln - 3
         else lv=nil
         end
         tag=if defined? dob.name and dob.name=~/\S+/
@@ -219,13 +217,9 @@ WOK
           n1=dob.ln
           n2=dob.ln + 1
           n3=dob.ln + 2
-          v=dob.ln - 3
+          dob.ln - 3
         else lv=nil
         end
-        tag=if defined? dob.name and dob.name=~/\S+/
-          "\n#{Ax[:tab]*n3}<nametag>#{dob.name}</nametag>"
-        else ''
-        end
         case lv
         when 1..3
           xml_el="<heading#{lv}>"
@@ -255,9 +249,7 @@ WOK
           end
         when 4..6
           6.downto(lv) do |x|
-            y=x - 1
             if @level[x]==true
-              u=x - 3;
               @xml_contents_close[x]=''
             end
           end
@@ -343,7 +335,7 @@ WOK
         dob
       end
       def table_structure(dob) #tables
-        table=SiSU_XHTML_Shared::TableXHTML.new(dob)
+        SiSU_XHTML_Shared::TableXHTML.new(dob)
       end
       def markup(data)
         xml_sc(@md)
@@ -400,7 +392,7 @@ WOK
                     dob.obj=x.heading_body6
                   end
                 else
-                  ocn=dob.ocn
+                  dob.ocn
                   if dob.is==:verse
                     type='verse'
                     poem_structure(dob) #redo
@@ -482,7 +474,6 @@ WOK
       end
       def pre
         rdf=SiSU_XML_Tags::RDF.new(@md)
-        dir=SiSU_Env::InfoEnv.new
         stylesheet=SiSU_Style::CSS_HeadInfo.new(@md,'xml_dom').stylesheet
         encoding=if @sys.locale =~/utf-?8/i; '<?xml version="1.0" encoding="UTF-8" standalone="no"?>'
         else                                 '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
