@@ -111,7 +111,7 @@ module  SiSU_CGI_PgSQL
         else STDERR.puts "WARNING: no postgresql database available, (have you created one?)"
         end
         serve=serve.sort
-        f1,f2,f3='','',''
+        f1,f2='',''
         serve.each do |x|
           f1 << %{              <option value="#{Db[:name_prefix]}#{x}">#{x}</option>\n} unless x =~/apache|sisu\/image/ #check
         end
