@@ -78,7 +78,7 @@ module SiSU_Concordance
     def read
       begin
         @env,@md=@particulars.env,@particulars.md
-        loc=@env.url.output_tell
+        @env.url.output_tell
         unless @md.opt.cmd =~/q/
           tool=(@md.opt.cmd =~/[MVv]/) \
           ? "#{@env.program.web_browser} #{@md.file.output_path.html_concordance.dir}/#{@md.file.base_filename.html_concordance}"
@@ -116,7 +116,6 @@ module SiSU_Concordance
         @particulars,@md=particulars,particulars.md
         @data=SiSU_HTML::Source::HTML_Environment.new(particulars).tuned_file_instructions
         @file=SiSU_Env::FileOp.new(@md)
-        txt_path=%{#{@md.dir_out}}
         @fnb=@md.fnb
         @lex_button=%{<a href="http://www.jus.uio.no/sisu/" target="_top"><img border="0" height="44" width="144" valign="center" src="#{@file.path_rel_links.html_seg_2}_sisu/image/sisu.png" alt="SiSU home --&gt;"></a>}
         @doc_details =<<WOK
@@ -334,7 +333,6 @@ WOK
             end
           end
         end
-        scr='<font size="1" color="#777777" face=times new roman><img border="0" height="15" width="15" src="../_sisu/image/b_doc.png" alt="Full Text">&nbsp;scroll:&nbsp;</font><font size="1" color="#222222" face=times new roman>doc#&nbsp;</font> '
         seg=''
         head=SiSU_Concordance::Source::DocTitle.new(@particulars).create
         head=head.gsub(/#{Xx[:html_relative2]}/m,@file.path_rel_links.html_seg_2).
@@ -360,7 +358,6 @@ WOK
           keyword=SiSU_Concordance::Source::Word.new(word,@freq[word]).html
           if keyword !~ @rxp_excluded0
             if @word_map[word][0] =~ /\d+/
-              wm=[]
               @file_concordance << %{#{keyword}#{seg}#{@word_map[word].uniq.compact.join}}
             end
             @file_concordance << '</p>'
