@@ -151,7 +151,6 @@ module  SiSU_DBI_Discrete                               #% database building
     end
     def connect
       begin
-        sql_type='sqlite'
         SiSU_Screen::Ansi.new(@opt.cmd,"DBI (#{@sql_type}) #{@opt.mod}",@opt.fns).dbi_title unless @opt.cmd =~/q/
         @db.sqlite_discrete.conn_sqlite3
       rescue
@@ -165,7 +164,7 @@ module  SiSU_DBI_Discrete                               #% database building
     end
     def sql_maintenance_file
       file=if @opt.inspect =~/M/
-        x=if @opt.fns and not @opt.fns.empty?
+        if @opt.fns and not @opt.fns.empty?
           @env=SiSU_Env::InfoEnv.new(@opt.fns) if @opt.fns
           puts "\n#{@env.processing_path.sqlite}/#{@opt.fns}.sql" if @sql_type =~/sqlite/ and @opt.cmd =~/M/
           @db=SiSU_Env::InfoDb.new
