@@ -185,7 +185,7 @@ module SiSU_HTML_Seg
     end
   protected
     def articles(data)
-      track,tracking,newfile=0,0,0
+      tracking,newfile=0,0
       @@is4=@@is3=@@is2=@@is1=0
       printed_endnote_seg='n'
       idx_html=nil
@@ -200,7 +200,7 @@ module SiSU_HTML_Seg
         || dob.is == :heading_insert) \
         && dob.ln == 4
           @@seg_name << dob.name
-          seg_name=dob.name
+          dob.name
         end
       end
       @@seg_name_html=@@seg_name
@@ -257,7 +257,7 @@ module SiSU_HTML_Seg
           if not (dob.is==:heading \
           || dob.is==:heading_insert) \
           && dob.ln==1
-            head1=$_ #; check
+            $_ #; check
           end
         end
         if @@is4==1
@@ -268,8 +268,6 @@ module SiSU_HTML_Seg
             || dob.is==:heading_insert) \
             && dob.ln==4
               if tracking != 0
-                dirout=SiSU_Env::InfoEnv.new(@md.fns)
-                dir_sisu=dirout.path.output
                 @file=SiSU_Env::FileOp.new(@md)
                 unless FileTest.directory?(@file.output_path.html_seg.dir)
                   FileUtils::mkdir_p(@file.output_path.html_seg.dir) if File.writable?("#{@file.output_path.base.dir}/.")
@@ -426,7 +424,7 @@ module SiSU_HTML_Seg
     end
     def markup(dob)
       @debug=[]
-      format_head_seg=SiSU_HTML_Format::HeadSeg.new(@md)
+      SiSU_HTML_Format::HeadSeg.new(@md)
       if dob.is !=:meta
         if dob.is==:heading \
         || dob.is==:heading_insert \
@@ -439,7 +437,7 @@ module SiSU_HTML_Seg
         || dob.is==:para
           dob_html=if dob.is==:heading \
           || dob.is==:heading_insert
-            x=if dob.ln==4
+            if dob.ln==4
               sto.seg_heading4
             elsif dob.ln==5
               sto.seg_heading5
