@@ -129,10 +129,10 @@ module SiSU_HTML_Tune
         songsheet_array(@data)
         #data=songsheet_array(@data)
         if @md.opt.cmd =~/M/  #Hard Output Tune Optional on/off here
-          data=SiSU_HTML_Tune::Output.new(@data,@md).hard_output
+          SiSU_HTML_Tune::Output.new(@data,@md).hard_output
           SiSU_HTML_Tune::Output.new(@data,@md).marshal
         end
-        tuned=SiSU_HTML_Tune::Tune.new(@data,@md).output
+        SiSU_HTML_Tune::Tune.new(@data,@md).output
       rescue
         SiSU_Errors::InfoError.new($!,$@,@md.opt.cmd,@md.fns).error do
           __LINE__.to_s + ':' + __FILE__
