@@ -121,7 +121,6 @@ module SiSU_QRcode
         fn=@f.base_filename.manifest_txt
         mn=''
         if @md.opt.cmd =~/M/
-          pt=@f.output_path.manifest.dir
           fn=@f.base_filename.manifest_txt
           manifest=@f.write_file.manifest_txt
         end
@@ -132,26 +131,16 @@ module SiSU_QRcode
           mn += x
         end
         manifest.close if @md.opt.cmd =~/M/
-        #system(%{
-        #  cat  #{pt}/#{fn} | qrencode -s 3 -o qrcm.autonomy_markup0.png
-        #})
         cmd=SiSU_Env::SystemCall.new(mn,@f.place_file.qrcode_md.dir,@md.opt.cmd)
         cmd.qrencode
-        #system(%{
-        #  echo "#{mn}" | qrencode -s 3 -o #{@dest}/qrc_md.#{fn}.png
-        #})
       end
       def output_metadata_short
-        fn=@f.base_filename.manifest_txt
         mn=''
         @manifest[:txt_title].each do |x|
           mn += x
         end
         cmd=SiSU_Env::SystemCall.new(mn,@f.place_file.qrcode_title.dir,@md.opt.cmd)
         cmd.qrencode
-        #system(%{
-        #  echo "#{mn}" | qrencode -s 3 -o #{@dest}/qrc_title.#{fn}.png
-        #})
       end
       def summarize(id,file,pth='',rel='',url='',img='● ')
         size=(File.size("#{pth}/#{file}")/1024.00).to_s
@@ -213,22 +202,14 @@ WOK
             @m << { mu: mu, l: lng }
           end
         end
-        #url=@f.output_path.base.url
-        #@en_manifest=if @env.output_dir_structure.by_language_code?
-        #  "#{url}/en/manifest/#{@md.fnb}.html"
-        #elsif @env.output_dir_structure.by_filetype?
-        #  "#{url}/manifest/#{@md.fnb}.#{lc}.html"
-        #else
-        #  "#{url}/sisu_manifest.#{lc}.html"
-        #end
-        manifests
+        #manifests
         @m=@m.uniq
         @m
       end
       def languages(id,file)
         flv=published_manifests?
         flv.each do |l|
-          lang=SiSU_Translate::Source.new(@md,@language,l[:n]).language_list
+          SiSU_Translate::Source.new(@md,@language,l[:n]).language_list
           @manifest[:txt] << "#{l[:mu]} #{l[:l]}\n"
         end
       end
@@ -446,7 +427,6 @@ WOK
       end
       def source_tests
         if @md.fns =~/\.ssm\.sst$/                                                  #% decide whether to extract and include requested/required documents
-          req=@md.fns
           if FileTest.file?(@f.place_file.src.dir)==true
             pth=@f.output_path.src.dir
             rel=@f.output_path.src.rel
@@ -709,8 +689,6 @@ WOK
       end
       def check_output(data)
         begin
-          id,file='',''
-          vz=SiSU_Viz::Defaults.new
           @f=SiSU_Env::FileOp.new(@md) #.base_filename
           url=@f.output_path.base.url
           @en_manifest=if @env.output_dir_structure.by_language_code?
