@@ -127,7 +127,7 @@ module SiSU_Sitemaps
     def sitemap_index
       sitemap_files=Dir.glob("#{@env.path.sitemaps}/sitemap_*.xml")
       sitemap_idx=[]
-      sitemap_idx <<<<WOK
+      sitemap_idx << <<WOK
 <?xml version="1.0" encoding="UTF-8"?>
 <sitemapindex xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    xsi:schemaLocation="http://www.sitemaps.org/schemas/sitemaps/0.9
@@ -137,19 +137,19 @@ WOK
       sitemap_files.each do |s|
         f=s.gsub(/.+?\/sitemap_([^\/]+?)\.xml$/,'\1')
         @trans.char_enc.utf8(f) if @sys.locale =~/utf-?8/i #% utf8
-sitemap_idx <<<<WOK
+sitemap_idx << <<WOK
   <sitemap>
     <loc>#{@env.path.url.remote}/#{f}/sitemap.xml</loc>
   </sitemap>
 WOK
       end
-      sitemap_idx <<<<WOK
+      sitemap_idx << <<WOK
 </sitemapindex>
 WOK
-      idx=sitemap_idx.join
+      sitemap_idx.join
     end
     def sitemap
-      map=if defined? @md.date.modified \
+      if defined? @md.date.modified \
       and @md.date.modified=~/\d{4}-\d{2}-\d{2}/
         sitemap_date_modified
       else sitemap_no_date
