@@ -112,7 +112,7 @@ module SiSU_TeX
         @md=@particulars.md
         SiSU_Screen::Ansi.new(@opt.cmd,'LaTeX/PDF',"[#{@opt.f_pth[:lng_is]}] #{@opt.fno}").green_title_hi unless @opt.cmd =~/q/
         if @opt.cmd =~/[MVv]/
-          path=@env.url.output_tell
+          @env.url.output_tell
           if @md.opt.act[:pdf_l][:set]==:on
             SiSU_Screen::Ansi.new(@opt.cmd,@opt.fns,"#{@env.program.pdf_viewer} #{@md.file.output_path.pdf.dir}/#{@md.file.base_filename.pdf_l}pdf").flow
           end
@@ -229,7 +229,6 @@ module SiSU_TeX
           pwd=Dir.pwd
           Dir.chdir(pwd) #watch
           @tex_f_no=0
-          info={}
           if FileTest.file?(@env.source_file_with_path)
             @md.papersize_array.each do |ps|
               if @md.fns =~/\.(?:-|ssm\.)?sst$/
@@ -505,8 +504,6 @@ module SiSU_TeX
         dob
       end
       def markup_common(dob)
-        tex_f=nil
-        txt_obj={ dal: dob }
         if dob.of==:block
           @lineone=if dob.is==:block \
           || dob.is==:group \
@@ -711,7 +708,6 @@ module SiSU_TeX
       end
       def markup(data)
         @tex_file=[]
-        md={}
         home=@vz.txt_home.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}|#{Mx[:br_paragraph]}|\\\\/,' - ') #no line splitting in heading neither html nor latex
         title=@md.title.full.gsub(/#{Mx[:br_line]}|#{Mx[:br_nl]}|#{Mx[:br_paragraph]}|\\\\/,' - ') #no line splitting in heading neither html nor latex
         @md.papersize_array.each do |ps|
@@ -726,7 +722,7 @@ module SiSU_TeX
             @@tex_head[ps][:l]=orient_landscape.document_head_with_orientation(@codeblock_box)
           end
         end
-        @tex_file <<<<-WOK
+        @tex_file << <<-WOK
 #{@tex_ml.header}#{@tex_ml.footer}
 \\tolerance=300
 \\clubpenalty=300
@@ -757,9 +753,6 @@ module SiSU_TeX
 % \\sloppy
 \\begin{document}
         WOK
-        sisu_rc_footnote=if @md.sc_info then @tex_ml.doc_sc_info_footnote_full
-        else                                 @tex_ml.doc_sc_info_footnote_brief
-        end
         @copymark='' #check and remove as now is superflous
         x={}
         txt_obj={ title: @md.title.full }
@@ -800,7 +793,7 @@ module SiSU_TeX
         @tex_file << unless @md.fnb =~/^mail\s*$/ then @tex_ml.site
         else                                           '\date'
         end
-        @tex_file <<<<-WOK
+        @tex_file << <<-WOK
 \\pagenumbering{roman}\\maketitle
 \\pagestyle{fancy}
         WOK
@@ -911,7 +904,6 @@ module SiSU_TeX
         dob
       end
       def number_paras(data)
-        tex_file=[]
         data.each do |dob|
           dob=if dob.is_a?(Hash)
             if ( dob['a4'] \
