@@ -84,8 +84,6 @@ module SiSU_XHTML
       begin
         @env,@md,@dal_array=@particulars.env,@particulars.md,@particulars.dal_array
         unless @opt.cmd =~/q/
-          path=@env.path.output_tell
-          loc=@env.url.output_tell
           tool=if @opt.cmd =~/[MV]/
             "#{@env.program.web_browser} file://#{@md.file.output_path.xhtml.dir}/#{@md.file.base_filename.xhtml}"
           elsif @opt.cmd =~/v/
@@ -196,7 +194,7 @@ WOK
         if defined? dob.tags \
         and dob.tags.length > 0 # insert tags "hypertargets"
           dob.tags.each do |t|
-            tags=tags +%{<named id="#{t}" />}
+            tags=tags << %{<named id="#{t}" />}
           end
         end
         tags
@@ -207,8 +205,7 @@ WOK
           named=name_tags(dob)
           if dob.is==:heading
             lv=dob.ln
-            n=dob.ln - 1
-            n3=dob.ln + 2
+            dob.ln + 2
           else lv=nil
           end
           extract_endnotes(dob)
@@ -367,7 +364,6 @@ WOK
       end
       def pre
         rdf=SiSU_XML_Tags::RDF.new(@md)
-        dir=SiSU_Env::InfoEnv.new
         @@xml[:head],@@xml[:body]=[],[]
         stylesheet=SiSU_Style::CSS_HeadInfo.new(@md,'xhtml').stylesheet
         encoding=(@sys.locale =~/utf-?8/i) ? '<?xml version="1.0" encoding="UTF-8" standalone="no"?>' : '<?xml version="1.0" encoding="ISO-8859-1" standalone="no"?>'
